"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.creator = exports.messages = void 0;
const regexp_string_matcher_1 = require("@textlint/regexp-string-matcher");
const escape_string_regexp_1 = __importDefault(require("escape-string-regexp"));
const os_1 = __importDefault(require("os"));
const multiplatformPath = (dirPath) => {
    return new RegExp(dirPath
        .split(/[\/¥]/)
        .map((pathinfo) => escape_string_regexp_1.default(pathinfo))
        .join("[/¥]"), "g");
};
exports.messages = {
    HOMEDIR: {
        en: (props) => `found user's homedir path: ${props.PATH}`,
        ja: (props) => `ユーザーホームのパスが見つかりました: ${props.PATH}`,
    },
};
function reportIfFoundHomedir({ source, options, context, t, getUserHomeDirPattern, }) {
    const homedirPattern = getUserHomeDirPattern();
    const results = source.content.matchAll(homedirPattern);
    for (const result of results) {
        const index = result.index || 0;
        const match = result[0] || "";
        const range = [index, index + match.length];
        const allowedResults = regexp_string_matcher_1.matchPatterns(match, options.allows);
        if (allowedResults.length > 0) {
            continue;
        }
        context.report({
            message: t("HOMEDIR", {
                PATH: match,
            }),
            range,
        });
    }
}
exports.creator = {
    messages: exports.messages,
    meta: {
        id: "@secretlint/secretlint-rule-no-homedir",
        recommended: true,
        type: "scanner",
        supportedContentTypes: ["text"],
        docs: {
            url: "https://github.com/secretlint/secretlint/blob/master/packages/%40secretlint/secretlint-rule-no-homedir/README.md",
        },
    },
    create(context, options) {
        var _a;
        const t = context.createTranslator(exports.messages);
        const normalizedOptions = {
            allows: options.allows || [],
        };
        const userHomeDirPattern = multiplatformPath((_a = options._debugHomeDir) !== null && _a !== void 0 ? _a : os_1.default.homedir());
        /**
         * Clone RegExp to avoid reuse lastIndex
         */
        const getUserHomeDirPattern = () => {
            return new RegExp(userHomeDirPattern.source, userHomeDirPattern.flags);
        };
        return {
            file(source) {
                reportIfFoundHomedir({ source, options: normalizedOptions, context, t, getUserHomeDirPattern });
            },
        };
    },
};
exports.default = exports.creator;
//# sourceMappingURL=index.js.map